( cd usr/lib ; rm -rf libvgagl.so.1 )
( cd usr/lib ; ln -sf libvgagl.so.1.2.10 libvgagl.so.1 )
( cd usr/lib ; rm -rf libvga.so.1 )
( cd usr/lib ; ln -sf libvga.so.1.2.10 libvga.so.1 )
( cd usr/lib ; rm -rf libvga.so )
( cd usr/lib ; ln -sf libvga.so.1 libvga.so )
( cd usr/lib ; rm -rf libvgagl.so )
( cd usr/lib ; ln -sf libvgagl.so.1 libvgagl.so )
